[//]: # (future) The future for eh
# Future features

- Expanded eh config (**ehrc**)
    - Config from home for color options
    - Multiple topic repositories
    - Personal topic repositories
    - Less verbose usage configuration
- A simple website that performs the same actions
- History logging
- Metadata tagging for topics

# Debt

- Need to simplify the whole `base_subject` madness
- Rename all the subject bs to topics
- Fix versioning and release poopiness
